@@ -9,8 +9,8 @@ from django.conf import settings
 from django.core import exceptions
 from django.db import models
 from django.utils import timezone
-from django.utils.encoding import smart_str, smart_text
-from django.utils.translation import ugettext as _
+from django.utils.encoding import smart_str
+from django.utils.translation import gettext as _
 
 from django_jalali import forms
 
@@ -166,7 +166,7 @@ class jDateField(models.DateField):
 
         if lookup_type in ('month', 'day', 'week_day'):
             raise ValueError(
-                "jDateField dosn't work with month, day and week_day !")
+                "jDateField doesn't work with month, day and week_day !")
 
         return super().get_prep_lookup(lookup_type, value)
 
@@ -190,7 +190,7 @@ class jDateField(models.DateField):
         if value is None:
             date_string = ''
         else:
-            date_string = smart_text(value)
+            date_string = smart_str(value)
         return date_string
 
     def formfield(self, **kwargs):
@@ -381,7 +381,7 @@ class jDateTimeField(models.DateTimeField):
         if value is None:
             date_string = ''
         else:
-            date_string = smart_text(value)
+            date_string = smart_str(value)
         return date_string
 
     def contribute_to_class(self, cls, name):
@@ -421,7 +421,7 @@ class jDateTimeField(models.DateTimeField):
 
         if lookup_type in ('month', 'day', 'week_day'):
             raise ValueError(
-                "jDateField dosn't work with month, day and week_day !")
+                "jDateTimeField doesn't work with month, day and week_day !")
 
         return super().get_prep_lookup(lookup_type, value)
 
